==> polls-v1.4.1.zip: polls/messages/eu/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Oharra:</strong> emaitza ezkutatuta egongo da moderatzaile batek inkesta itxi arte.',
    'Access denied!' => 'Sarrera debekatua!',
    'Add answer...' => 'Gehitu erantzuna...',
    'Again? ;Weary;' => 'Berriro? ;Nekatuta;',
    'Allows the user to create polls' => 'Erabiltzaileari inkestak sortzeko aukera ematen dio',
    'Allows to start polls.' => 'Inkestak hasteko aukera ematen du.',
    'Anonymous' => 'Anonimoa',
    'Anonymous Votes?' => 'Bozka anonimoak?',
    'Anonymous poll!' => 'Inkesta anonimoa!',
    'Answers' => 'Galderak',
    'At least one answer is required' => 'Gutxienez erantzun bat behar da',
    'Cancel' => 'Utzi bertan behera',
    'Close Poll' => 'Inkesta osoa',
    'Closed' => 'Itxita',
    'Club A Steakhouse' => 'Club A erretegia',
    'Could not load poll!' => 'Ezin izan da inkesta kargatu!',
    'Create poll' => 'Sortu inkesta',
    'Description' => 'Deskribapena',
    'Display answers in random order?' => 'Erantzunak ausazko ordenean erakutsi nahi dituzu?',
    'Edit answer (empty answers will be removed)...' => 'Editatu erantzuna (hutsik dauden erantzunak kenduko dira)...',
    'Edit your poll question...' => 'Editatu zure inkestako galdera...',
    'Hide results until poll is closed?' => 'Inkesta itxi arte emaitzak ezkutatu ?',
    'Invalid answer!' => 'Erantzun baliogabea!',
    'Location of the next meeting' => 'Hurrengo bileraren kokapena',
    'Multiple answers per user' => 'Hainbat erantzun erabiltzaile bakoitzeko',
    'Pisillo Italian Panini' => 'Pisillo italiar paninia',
    'Please specify at least {min} answers!' => 'Mesedez, zehaztu zerrendan gutxienez {min} erantzun!',
    'Poll' => 'Inkesta',
    'Polls' => 'Inkestak',
    'Question' => 'Galdera',
    'Reopen Poll' => 'Ireki berriro inkesta',
    'Reset my vote' => 'Ezabatu nire botua',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Oraintxe bertan, gure hurrengo topaketaren urratsak planifikatzen ari gara eta nora joan nahi duzun jakin nahiko genuke.',
    'Save' => 'Gorde',
    'To Daniel' => 'Danielentzat',
    'Users voted for: <strong>{answer}</strong>' => 'Erabiltzaileek ondorengoa bozkatu dute: <strong>{answer}</strong>',
    'Vote' => 'Bozkatu',
    'Voting for multiple answers is disabled!' => 'Erantzun anitzeko botoa desgaituta dago!',
    'Whenever someone participates in a poll.' => 'Norbaitek inkesta batean parte hartzen duen aldiro.',
    'Why don\'t we go to Bemelmans Bar?' => 'Zergatik ez gara Bemelmans tabernara joaten?',
    'You have insufficient permissions to perform that operation!' => 'Ez duzu baimen nahikorik eragiketa hori egiteko!',
    'and {count} more vote for this.' => 'eta {count} boto gehiago honen alde.',
    'votes' => 'Botuak',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} erabiltzaileak {question} erantzun du.',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/eu/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Oharra:</strong> emaitza ezkutatuta egongo da moderatzaile batek inkesta itxi arte.',
    'Access denied!' => 'Sarrera debekatua!',
    'Add answer...' => 'Gehitu erantzuna...',
    'Again? :weary:' => 'Berriro? ;Nekatuta;',
    'Allows the user to create polls' => 'Erabiltzaileari inkestak sortzeko aukera ematen dio',
    'Allows to start polls.' => 'Inkestak hasteko aukera ematen du.',
    'Anonymous' => 'Anonimoa',
    'Anonymous Votes?' => 'Bozka anonimoak?',
    'Anonymous poll!' => 'Inkesta anonimoa!',
    'Answers' => 'Galderak',
    'At least one answer is required' => 'Gutxienez erantzun bat behar da',
    'Cancel' => 'Utzi bertan behera',
    'Close Poll' => 'Inkesta osoa',
    'Closed' => 'Itxita',
    'Club A Steakhouse' => 'Club A erretegia',
    'Could not load poll!' => 'Ezin izan da inkesta kargatu!',
    'Create poll' => 'Sortu inkesta',
    'Description' => 'Deskribapena',
    'Display answers in random order?' => 'Erantzunak ausazko ordenean erakutsi nahi dituzu?',
    'Edit answer (empty answers will be removed)...' => 'Editatu erantzuna (hutsik dauden erantzunak kenduko dira)...',
    'Edit your poll question...' => 'Editatu zure inkestako galdera...',
    'Hide results until poll is closed?' => 'Inkesta itxi arte emaitzak ezkutatu ?',
    'Invalid answer!' => 'Erantzun baliogabea!',
    'Location of the next meeting' => 'Hurrengo bileraren kokapena',
    'Multiple answers per user' => 'Hainbat erantzun erabiltzaile bakoitzeko',
    'Pisillo Italian Panini' => 'Pisillo italiar paninia',
    'Please specify at least {min} answers!' => 'Mesedez, zehaztu zerrendan gutxienez {min} erantzun!',
    'Poll' => 'Inkesta',
    'Polls' => 'Inkestak',
    'Question' => 'Galdera',
    'Reopen Poll' => 'Ireki berriro inkesta',
    'Reset my vote' => 'Ezabatu nire botua',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Oraintxe bertan, gure hurrengo topaketaren urratsak planifikatzen ari gara eta nora joan nahi duzun jakin nahiko genuke.',
    'Save' => 'Gorde',
    'To Daniel' => 'Danielentzat',
    'Users voted for: <strong>{answer}</strong>' => 'Erabiltzaileek ondorengoa bozkatu dute: <strong>{answer}</strong>',
    'Vote' => 'Bozkatu',
    'Voting for multiple answers is disabled!' => 'Erantzun anitzeko botoa desgaituta dago!',
    'Whenever someone participates in a poll.' => 'Norbaitek inkesta batean parte hartzen duen aldiro.',
    'Why don\'t we go to Bemelmans Bar?' => 'Zergatik ez gara Bemelmans tabernara joaten?',
    'You have insufficient permissions to perform that operation!' => 'Ez duzu baimen nahikorik eragiketa hori egiteko!',
    'and {count} more vote for this.' => 'eta {count} boto gehiago honen alde.',
    'votes' => 'Botuak',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} erabiltzaileak {question} erantzun du.',
    'Poll content ID' => '',
];
